blueye.sdk.constants - Blueye SDK

Skip to content

# Module blueye.sdk.constants

This file contains constants used by the SDK.

View Source

    """

    This file contains constants used by the SDK.

    """

    class WaterDensities:

        """

        Various typical densities for salt water (in grams/liter)

        """

        fresh = 997.0

        brackish = 1011.0

        salty = 1025.0

## Classes

### WaterDensities

    class WaterDensities(
        /,
        *args,
        **kwargs
    )

Various typical densities for salt water (in grams/liter)

View Source

    class WaterDensities:

        """

        Various typical densities for salt water (in grams/liter)

        """

        fresh = 997.0

        brackish = 1011.0

        salty = 1025.0

#### Class variables

    brackish

    fresh

    salty